------------------------------------------------------------------------------
-- MakeMeGetMyMain - Alarms you when something happens to your character
------------------------------------------------------------------------------
-- GUI.lua - Interface
--
-- Author: Expelliarm5s / July 2020 / All Rights Reserved
--
-- Version 1.1.5
------------------------------------------------------------------------------
-- luacheck: ignore 212 globals DLAPI UISpecialFrames

local addonName, addon = ...
local modle = addon:NewModule("GUI", "AceEvent-3.0", "AceConsole-3.0")
-- local L = LibStub("AceLocale-3.0"):GetLocale(addonName)
local AceGUI = LibStub("AceGUI-3.0")
local private = {}
------------------------------------------------------------------------------

private.display = nil

function modle:DebugPrintf(...)
	if addon.isDebug then
		local status, res = pcall(format, ...)
		if status then
			addon:DebugLog("GUI~" .. res)
		end
	end
end

function modle:Close()
	private.display.frame.obj:Fire("OnClose")
end

function modle:Fire(m)
	modle:DebugPrintf("Fire in module " .. m)

	if not private.display then
		local display = AceGUI:Create("Frame")
		display.frame:SetFrameStrata("MEDIUM")
		display.frame:SetWidth(900)
		display.frame:SetHeight(800)

		modle:DebugPrintf("  created the new Frame widget %s", tostring(display))

		local title = "|cFF33FF99" .. addon.METADATA.NAME .. " (" .. addon.METADATA.VERSION .. ")|r"
		display:SetTitle(title)
		display:SetLayout("Fill")
		display:SetStatusText("--")
		display:EnableResize(true)

		display:SetCallback("OnClose", function(_display)
			AceGUI:Release(_display)
			private.display = nil
			_G[addonName .. "Frame"] = nil
			-- collectgarbage()
		end)

		private.content = AceGUI:Create("ScrollFrame")
		private.content:SetLayout("Flow")
		display:AddChildren(private.content)

		if addon.db.global.closeOnEscape then
			_G[addonName .. "Frame"] = display.frame
			tinsert(UISpecialFrames, addonName .. "Frame")
		else
			_G[addonName .. "Frame"] = nil
		end

		private.display = display
	end

	local b = AceGUI:Create("Icon")
	b:SetLabel(m)
	local icon = "INTERFACE\\ICONS\\INV_Misc_QuestionMark"
	if addon[m].ModuleIcon then
		icon = addon[m].ModuleIcon()
	end
	b:SetImage(icon)
	b:SetImageSize(180,180)
	private.content:AddChildren(b)

	if addon.db.global.windowTransparent then
		private.display.frame:SetBackdropColor(0,0,0,0)
	else
		private.display.frame:SetBackdropColor(0.2,0.2,0.2,1)
	end

	-- relocate to allow looting
	if private.display.frame:GetParent() then
		if not addon.db.global.windowFullMode then
			private.display.frame:SetPoint("TOP", private.display.frame:GetParent(), "TOP", 0, -50)
			private.display.frame:SetPoint("BOTTOM", private.display.frame:GetParent(), "CENTER", 0, 120)
		else
			private.display.frame:SetPoint("TOP", private.display.frame:GetParent(), "TOP", 0, -150)
			private.display.frame:SetPoint("BOTTOM", private.display.frame:GetParent(), "BOTTOM", 0, 150)
		end
	end

	private.display:Show()

	addon.Options.PlaySound(addon.db.global["Sound" .. m])

end

-- EOF
